@@ -20,25 +20,32 @@ def test_dict_dump(alert):
 
 def test_json_dump(alert):
     print('---- json dump ----')
-    pprint(alert.as_json())
+    print(alert.as_json())
 
 
 if __name__ == '__main__':
     # first command line arg is assumed to be a full URL to a CAP
     import requests
 
-    if len(sys.argv) > 1:
-        cap_url = sys.argv[1]
-        response = requests.get(cap_url)
-        src = response.text
-    # testing
-    else:
-        filepath = r'cap.IL124CA04A2F50.SevereThunderstormWarning.xml'
+    def TestLocalXML():
+        print('--Testing parse of a local XML file---')
+
+        filepath = r'cap.2020-05-07T14_12_00.xml'
         with open(filepath, 'rt') as file:
             src = file.read()
 
-    alert = NWSCAPParser(src)
-    print(alert)
-    test_basic_fields(alert)
-    test_dict_dump(alert)
-    test_json_dump(alert)
+        cap = NWSCAPParser(rawXML=src)
+
+        for ID, entry in cap.entries.items():
+            print('ID=', ID, ', entry=', entry)
+
+    def TestRemoteURL():
+        print('--Testing parse of a remote file---')
+
+        cap = NWSCAPParser(url='http://alerts.weather.gov/cap/nc.php?x=1')
+
+        for ID, entry in cap.entries.items():
+            print('ID=', ID, ', entry=', entry)
+
+    TestLocalXML()
+    TestRemoteURL()
\ No newline at end of file
